MemEntry

Struct MemEntry 

pub struct MemEntry<T: PrimInt, A: Access, E: Endian> { /* private fields */ }
Representation of a single memory entry

Implementations

Source

impl<T: PrimInt, A: Access, E: Endian> MemEntry<T, A, E>

pub const unsafe fn from_ptr(ptr: *mut T) -> Self

Safety

The caller must guarantee that the provided address points to a hardware memory entry of size T with access A and endianness E.

pub const fn as_ptr(&self) -> *mut T

Source

impl<T: PrimInt, A: Read, E: Endian> MemEntry<T, A, E>

pub fn read(&self) -> T

Read the value of the hardware memory entry.

Source

impl<T: PrimInt, A: Write, E: Endian> MemEntry<T, A, E>

pub fn write(&mut self, value: T)

Write the provided value to the hardware memory entry.