peakrdl-rust
Generate Rust code for accessing control/status registers from a SystemRDL description.
This crate contains the types and traits implemented by the generated code and should be added as a dependency when using code generated by PeakRDL-rust. To actually generate the code, see the peakrdl-rust-build crate.
Refer to the crate documentation for detailed type information. For broader documentation on the PeakRDL-rust project, visit the PeakRDL-rust documentation on Read the Docs.
Changelog
The changelog for this crate can be found on GitHub.
License
This crate is licensed under either of
- Apache License, Version 2.0, (LICENSE-APACHE)
- MIT license (LICENSE-MIT)
at your option.
The python exporter is licensed under LGPL-2.1. See the docs for more information and FAQs.
Modules
- access
- Marker types for read/write access
- encode
- Types for enum-encoded field representations
- endian
- Register endianness implementations
- io
- Traits for customizing the register I/O implementation
- mem
- Memory abstraction used to read, write, and iterate over memory entries
- reg
- Register abstraction used to read, write, and modify register values
- version
- Version constants for this crate